******************************************************************************
* *
* TEXAS INSTRUMENTS INCORPORATED
* Standard Linear and Logic Group
* HSPICE Model for SN74ALVCH16501
* PROPERTY OF TEXAS INSTRUMENTS INCORPORATED. UNAUTHORIZED
* REPRODUCTION AND/OR DISTRIBUTION IS STRICTLY PROHIBITED.
*
* THIS PRODUCT IS PROTECTED UNDER COPYRIGHT LAW.
* CREATED 2005, (C) COPYRIGHT 2005, TEXAS INSTRUMENTS
* INCORPORATED, ALL RIGHTS RESERVED
*
* UNLESS THERE IS A SIGNED, WRITTEN AGREEMENT TO THE
* CONTRARY, TEXAS INSTRUMENTS (TI) IS PROVIDING THE IBIS
* MODELS AND WITHOUT ANY WARRANTY, EXPRESSED OR
* IMPLIED. TI ASSUMES NO LIABILITY FOR:
* 1) THE ACCURACY OF THE HSPICE MODELS PROVIDED TO YOUR
* COMPANY;
* 2) THE PROPER FUNCTIONING OF THESE HSPICE MODELS IN YOUR
* DESIGN OR FOR ANY RESULTING APPLICATIONS; OR
* 3) INFRINGEMENT OF PATENTS, COPYRIGHTS OR INTELLECTUAL
* PROPERTY RIGHTS RESULTING FROM YOUR USE OF THESE HSPICE
* MODELS.
*
* TI PROVIDES HSPICE MODELS AS A SERVICE TO OUR CUSTOMERS.
* YOU AND YOUR COMPANY SHALL NOT DISTRIBUTE, SELL OR GIVE
* THESE MODELS TO ANYONE ELSE WITHOUT PRIOR WRITTEN
* PERMISSION FROM TI.
*
* TI RESERVES THE RIGHT TO MAKE CHANGES TO OUR PRODUCTS OR
* TO DISCONTINUE ANY SEMICONDUCTOR PRODUCT OR SERVICE
* WITHOUT NOTICE, AND ADVISES OUR CUSTOMERS TO OBTAIN THE
* LATEST VERSION OF RELEVANT INFORMATION TO VERIFY, BEFORE
* PLACING ORDERS, THAT THE INFORMATION BEING RELIED ON IS
* CURRENT.
*
* PLEASE BE AWARE THAT YOUR RECEIPT AND USE OF THE HSPICE
* INFORMATION PROVIDED SHALL SERVE AS ACCEPTANCE OF THESE
* TERMS AND CONDITIONS. IF YOU DO NOT ACCEPT THESE TERMS,
* YOU SHOULD RETURN OR DESTROY THE HSPICE MODELS AND ANY
* OTHER ACCOMPANYING INFORMATION IMMEDIATELY.
************************************************************************
**** HSPICE EXECUTION OPTIONS ****
************************************************************************
*
.OPTIONS POST $ Enables HSPLOT interface
.OPTIONS ACCT OPTS $ Prints stats & option values used
.OPTIONS SPICE=1 $ Forces Berkeley compatibility
.OPTIONS GMIN=1E-10 $ Lowest allowable conductance values
.OPTIONS GMINDC=1E-10
.OPTIONS ITL1=400 $ Maximum DC iteration limit
.OPTIONS ITL4=40 $ Maximum transient iterations/timestep
.OPTIONS ITL5=0 $ No limit to total transient iterations
***********************************************************************
.OPTIONS search='./'

***********************************************************************
******Top level Subcircuit call (device call)
***********************************************************************
* .INCLUDE 'sn74alvch16501.inc'
X__SN74ALVCH16501 OEAB LEAB A1 GND A2 A3 VCC A4 A5 A6 GND A7 A8 A9 A10 A11
+ A12 GND A13 A14 A15 VCC A16 A17 GND A18 NOEBA LEBA GND CLKBA B18 GND B17 B16
+ VCC B15 B14 B13 GND B12 B11 B10 B9 B8 B7 GND B6 B5 B4 VCC B3 B2 GND B1 CLKAB
+ GND SN74ALVCH16501
*** PULSE PARAMETERS ***
.param PFREQ1=10MEG $ 1st pulse (clk) frequency
.param PRFT19=2ns $ rise/fall time
.param PDELAY1=5ns $ delay of 1st pulse
.param PVIN=1.8 $ input voltage
.param PVT=0.9 $ input threshold voltage
.param PMAX=140ns $ max SPICE delay time
.param PRFT='(PRFT19/0.8)' $ convert rise/fall time to 100$
.param PPD1='(1/PFREQ1)' $ period of 1st pulse
.param PPW1='((PPD1 - (PRFT*2))/2)' $ pulse width of 1st pulse

*** TRANSIENT START & START PARAMETERS ***
.param PSTART='PDELAY1' $ time input starts to transition.
.param PSTOP='PSTART+PMAX+20n' $
.TRAN 0.05n 'PSTOP' 'PSTART' 0.05n
.PRINT TRAN v(DATA)

* SET CONTROL INPUTS TO ENABLE OUTPUT
VC0 OEAB 0 pulse 'PVIN' 0 'PDELAY1' 'PRFT' 'PRFT' 38ns 80ns
VC1 LEAB 0 pulse 'PVIN' 0 'PDELAY1' 'PRFT' 'PRFT' 18ns 40ns
VC2 NOEBA 0 pulse 'PVIN' 0 'PDELAY1' 'PRFT' 'PRFT' 8ns 20ns
VC3 CLKAB 0 pulse 'PVIN' 0 'PDELAY1' 'PRFT' 'PRFT' 3ns 10ns

*** SET INPUT AND TEST OUTPUT TO GO LOW ****
VI0 A1 0 pulse 'PVIN' 0 'PDELAY1' 'PRFT' 'PRFT' 'PPW1' 'PPD1'


* CHANGE TO THE OUTPUT NODE
VDATA B1 DATA DC 0
RLOAD DATA VCC 1000

* VOLTAGE SUPPLIES
vnc nc 0 0
rnc nc 0 1

.param PVCC=1.8
.param PGND=0v
VVCC VCC 0 'PVCC'
VGND GND 0 'PGND'

.TEMP 40

* RESISTORS TO PREVENT DANGLING NODES
* R1G_1 OEAB 0 1G
* R1G_2 LEAB 0 1G
* R1G_3 A1 0 1G
* R1G_4 GND 0 1G
R1G_5 A2 0 1G
R1G_6 A3 0 1G
* R1G_7 VCC 0 1G
R1G_8 A4 0 1G
R1G_9 A5 0 1G
R1G_10 A6 0 1G
* R1G_11 GND 0 1G
R1G_12 A7 0 1G
R1G_13 A8 0 1G
R1G_14 A9 0 1G
R1G_15 A10 0 1G
R1G_16 A11 0 1G
R1G_17 A12 0 1G
* R1G_18 GND 0 1G
R1G_19 A13 0 1G
R1G_20 A14 0 1G
R1G_21 A15 0 1G
* R1G_22 VCC 0 1G
R1G_23 A16 0 1G
R1G_24 A17 0 1G
* R1G_25 GND 0 1G
R1G_26 A18 0 1G
* R1G_27 NOEBA 0 1G
R1G_28 LEBA 0 1G
* R1G_29 GND 0 1G
R1G_30 CLKBA 0 1G
R1G_31 B18 0 1G
* R1G_32 GND 0 1G
R1G_33 B17 0 1G
R1G_34 B16 0 1G
* R1G_35 VCC 0 1G
R1G_36 B15 0 1G
R1G_37 B14 0 1G
R1G_38 B13 0 1G
* R1G_39 GND 0 1G
R1G_40 B12 0 1G
R1G_41 B11 0 1G
R1G_42 B10 0 1G
R1G_43 B9 0 1G
R1G_44 B8 0 1G
R1G_45 B7 0 1G
* R1G_46 GND 0 1G
R1G_47 B6 0 1G
R1G_48 B5 0 1G
R1G_49 B4 0 1G
* R1G_50 VCC 0 1G
R1G_51 B3 0 1G
R1G_52 B2 0 1G
* R1G_53 GND 0 1G
* R1G_54 B1 0 1G
* R1G_55 CLKAB 0 1G
* R1G_56 GND 0 1G

.END
